% function [Freq, AvPowerdBm] = AverageMeasurement(Signal, Resolution, Tvideo, RBW, R)
% 
% This function performs the average measurement of signal. The FCC
% requirements are RBW = 1MHz and Video Integration Time <= 1ms
%
%   Resolution : temporal resolution of Signal    [s] 
%   Tvideo     : Video Integration Time           [s]
%   RBW        : Resolution Bandwidth             [Hz]
%   R          : Characteristic Antenna Impedance [OHm]
%
%
% Author: samuel.dubouloz@cea.fr, 
%         CEA-LETI - May, 2005
% 

function [Freq, AvPowerdBm] = AverageMeasurement(Signal, Resolution, Tvideo, RBW, R)

% Default values, Warning and Error Management
if nargin < 2, error('the temporal resolution is required')
elseif nargin == 2, R = 50; RBW = 1e6; Tvideo = 1e-3;
elseif nargin == 3, R = 50; RBW = 1e6;
elseif nargin == 4, R = 50; end
if(RBW ~= 1e6 || Tvideo > 1e-3), warning('!!! non FCC compliant conditions !!! '), end

% Useful constants
dt = Resolution;
N = round(Tvideo/Resolution);
if length(Signal) < N, error('Signal Duration < Video Integration Time'), end
df = 1/(N*dt);

% Frequency Axis
Freq = (0:1/N:(N-1)/(2*N))/dt;

% Multipling Signal by a Tvideo wide window
Signal = Signal(1:N);

% Fourier Tranform
SignalFT = fft(Signal)*dt;
SignalPSD = abs(sqrt(2)*SignalFT(1:end/2)).^2;
clear Signal SignalFT

% Slipping Integration with a RBW wide frequency window
lenRBW = round(RBW/df);
Measure = 1/(Tvideo) * conv(SignalPSD, ones(1,lenRBW))*df; 
clear SignalPSD

% Measure in V
Measure = Measure(lenRBW/2:end-lenRBW/2);

% Measure in dBm
AvPowerdBm = 10*log10(1/R * Measure) + 30;
